@@ -1,12 +1,3 @@
-"""
-AUTHOR: ABRAHAM ISRAEL
-CODE NAME: ABRAM 🐼
-GITHUB: https://github.com/israelabraham
-LINKEDIN: https://linkedin.com/in/abraham-israel
-EMAIL: israelvictory87@gmail.com
-"""
-
-
 def error_response(status, message):
     """
     Custom error response
